@@ -1,7 +1,11 @@
-from pkg_resources import get_distribution, DistributionNotFound
+#! /usr/bin/python
+# -*- coding: utf-8 -*-
+
+# Generic/Built-in
+from pkg_resources import get_distribution
+from pkg_resources import DistributionNotFound
 
 __project__ = 'z2n-periodogram'
-__name__ = 'z2n'
 __version__ = None
 __license__ = 'MIT'
 __author__ = 'Yohan Alexander'
@@ -20,10 +24,11 @@ except DistributionNotFound:
     VERSION = __project__ + '-' + '(local)'
 else:
     VERSION = __project__ + '-' + __version__
-    # Other Libraries
+    import click
     import matplotlib
-    # Defalt backend
-    matplotlib.use('qt4agg')
-    # Owned Libraries
-    from z2n.plot import Plot
-    from z2n.series import Series
+    try:
+        matplotlib.use('tkagg')
+    except ImportError:
+        click.secho("Failed to use interactive backend.", fg='red')
+        click.secho(
+            "Check Tkinter dependency: sudo apt-get install python3-tk""", fg='yellow')
